@@ -1,20 +1,20 @@
 -- Lock Database
-UPDATE databasechangeloglock SET LOCKED = TRUE, LOCKEDBY = 'runner-yfpexrfv8-project-33554404-concurrent-0-5sbje3y3 (100.64.9.45)', LOCKGRANTED = NOW() WHERE ID = 1 AND LOCKED = FALSE;
+UPDATE databasechangeloglock SET LOCKED = TRUE, LOCKEDBY = 'runner-yfpexrfv8-project-33554404-concurrent-0-w3zx56dl (100.64.5.128)', LOCKGRANTED = NOW() WHERE ID = 1 AND LOCKED = FALSE;
 
 -- *********************************************************************
 -- Update Database Script
 -- *********************************************************************
 -- Change Log: upgrade.changelog-up-to-5.0.0.xml
--- Ran at: 16/02/2026 13:56
+-- Ran at: 07/11/2025 16:08
 -- Against: squashtm@jdbc:postgresql://postgres/squashtest
--- Liquibase version: 4.29.2
+-- Liquibase version: 4.31.1
 -- *********************************************************************
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0::bmsaddek
 -- Update TM database version number
 UPDATE CORE_CONFIG SET VALUE = '5.0.0' WHERE STR_KEY = 'squashtest.tm.database.version';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 1, '9:0799604eb9eb2be7388f004c93851b31', 'update tableName=CORE_CONFIG', 'Update TM database version number', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 1, '9:0799604eb9eb2be7388f004c93851b31', 'update tableName=CORE_CONFIG', 'Update TM database version number', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5923-increase-max-size-for-databasechangelog::jprioux
 -- Increase max size for ID and author columns in databasechangelog table
@@ -22,7 +22,7 @@ ALTER TABLE DATABASECHANGELOG ALTER COLUMN ID TYPE VARCHAR(255) USING (ID::VARCH
 
 ALTER TABLE DATABASECHANGELOG ALTER COLUMN AUTHOR TYPE VARCHAR(255) USING (AUTHOR::VARCHAR(255));
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5923-increase-max-size-for-databasechangelog', 'jprioux', '../tm/tm.changelog-5.0.0.xml', NOW(), 2, '9:5a715f325ee62e13bad31a7a80e5f834', 'modifyDataType columnName=ID, tableName=DATABASECHANGELOG; modifyDataType columnName=AUTHOR, tableName=DATABASECHANGELOG', 'Increase max size for ID and author columns in databasechangelog table', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5923-increase-max-size-for-databasechangelog', 'jprioux', '../tm/tm.changelog-5.0.0.xml', NOW(), 2, '9:5a715f325ee62e13bad31a7a80e5f834', 'modifyDataType columnName=ID, tableName=DATABASECHANGELOG; modifyDataType columnName=AUTHOR, tableName=DATABASECHANGELOG', 'Increase max size for ID and author columns in databasechangelog table', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5745-Add-environment-variables-to-project::bmsaddek
 -- Add VALUE, ENTITY_TYPE columns to ENVIRONMENT_VARIABLE_BINDING Table
@@ -42,7 +42,7 @@ DROP INDEX idx_fk_ev_binding_server;
 
 ALTER TABLE ENVIRONMENT_VARIABLE_BINDING DROP CONSTRAINT uc_ev_server_bnd;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-Add-environment-variables-to-project', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 3, '9:34b52c25de5de744ff0549269c4608d1', 'addColumn tableName=ENVIRONMENT_VARIABLE_BINDING; createIndex indexName=idx_evb_entity_id, tableName=ENVIRONMENT_VARIABLE_BINDING; createIndex indexName=idx_evb_entity_type, tableName=ENVIRONMENT_VARIABLE_BINDING; dropForeignKeyConstraint baseTabl...', 'Add VALUE, ENTITY_TYPE columns to ENVIRONMENT_VARIABLE_BINDING Table', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-Add-environment-variables-to-project', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 3, '9:34b52c25de5de744ff0549269c4608d1', 'addColumn tableName=ENVIRONMENT_VARIABLE_BINDING; createIndex indexName=idx_evb_entity_id, tableName=ENVIRONMENT_VARIABLE_BINDING; createIndex indexName=idx_evb_entity_type, tableName=ENVIRONMENT_VARIABLE_BINDING; dropForeignKeyConstraint baseTabl...', 'Add VALUE, ENTITY_TYPE columns to ENVIRONMENT_VARIABLE_BINDING Table', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5745-environment-variable-data-migration-server-value::lmurat
 -- Migrate environment variable values in environment_variable_binding table when it's a server value
@@ -51,7 +51,7 @@ UPDATE ENVIRONMENT_VARIABLE_BINDING binding
         FROM ENVIRONMENT_VARIABLE_VALUE environmentvalue
       WHERE environmentvalue.BOUND_ENTITY_TYPE = 'TEST_AUTOMATION_SERVER' AND environmentvalue.EVB_ID = binding.EVB_ID;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-environment-variable-data-migration-server-value', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 4, '9:57bf95c62c3e20eca2c158416e42fdd9', 'sql', 'Migrate environment variable values in environment_variable_binding table when it''s a server value', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-environment-variable-data-migration-server-value', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 4, '9:57bf95c62c3e20eca2c158416e42fdd9', 'sql', 'Migrate environment variable values in environment_variable_binding table when it''s a server value', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5745-environment-variable-data-migration-default-value::lmurat
 -- Migrate environment variable values in environment_variable_binding table when project value doesn't exist in environment variable value table
@@ -63,7 +63,7 @@ INSERT INTO ENVIRONMENT_VARIABLE_BINDING (EV_ID, ENTITY_ID, ENTITY_TYPE, VALUE,
                 LEFT JOIN ENVIRONMENT_VARIABLE_VALUE projectvalue ON projectvalue.EVB_ID = binding.EVB_ID AND projectvalue.BOUND_ENTITY_TYPE = 'PROJECT' AND projectvalue.BOUND_ENTITY_ID = project.PROJECT_ID
          WHERE projectvalue.EVB_ID IS NULL);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-environment-variable-data-migration-default-value', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 5, '9:dba7448dee9efba52381240150b15cc2', 'sql', 'Migrate environment variable values in environment_variable_binding table when project value doesn''t exist in environment variable value table', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-environment-variable-data-migration-default-value', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 5, '9:dba7448dee9efba52381240150b15cc2', 'sql', 'Migrate environment variable values in environment_variable_binding table when project value doesn''t exist in environment variable value table', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5745-environment-variable-data-migration-project-value::lmurat
 -- Migrate environment variable values in environment_variable_binding table when project value exist in environment variable value table
@@ -73,7 +73,7 @@ INSERT INTO ENVIRONMENT_VARIABLE_BINDING (EV_ID, ENTITY_ID, ENTITY_TYPE, VALUE,
         INNER JOIN ENVIRONMENT_VARIABLE_VALUE environmentvalue ON environmentvalue.EVB_ID = binding.EVB_ID
         WHERE environmentvalue.BOUND_ENTITY_TYPE = 'PROJECT');
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-environment-variable-data-migration-project-value', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 6, '9:567c608bffe98976e95bae8826acca6f', 'sql', 'Migrate environment variable values in environment_variable_binding table when project value exist in environment variable value table', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-environment-variable-data-migration-project-value', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 6, '9:567c608bffe98976e95bae8826acca6f', 'sql', 'Migrate environment variable values in environment_variable_binding table when project value exist in environment variable value table', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5745-Drop-environment-variable-value-table::lmurat
 -- Drop old environment variable values
@@ -83,13 +83,13 @@ DROP TABLE ENVIRONMENT_VARIABLE_VALUE;
 
 ALTER TABLE ENVIRONMENT_VARIABLE_BINDING ADD CONSTRAINT uc_evb_id_type_ev_id_binding UNIQUE (ENTITY_ID, ENTITY_TYPE, EV_ID);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-Drop-environment-variable-value-table', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 7, '9:ea40aa1227bd9ee3e47a46a48e710dab', 'dropColumn columnName=bound_server_id, tableName=ENVIRONMENT_VARIABLE_BINDING; dropTable tableName=ENVIRONMENT_VARIABLE_VALUE; addUniqueConstraint constraintName=uc_evb_id_type_ev_id_binding, tableName=ENVIRONMENT_VARIABLE_BINDING', 'Drop old environment variable values', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-Drop-environment-variable-value-table', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 7, '9:ea40aa1227bd9ee3e47a46a48e710dab', 'dropColumn columnName=bound_server_id, tableName=ENVIRONMENT_VARIABLE_BINDING; dropTable tableName=ENVIRONMENT_VARIABLE_VALUE; addUniqueConstraint constraintName=uc_evb_id_type_ev_id_binding, tableName=ENVIRONMENT_VARIABLE_BINDING', 'Drop old environment variable values', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5745-Add-environment-variables-type-to-denormalized-environment-variable::bmsaddek
 -- Add TYPE column to DENORMALIZED_ENVIRONMENT_VARIABLE Table
 ALTER TABLE DENORMALIZED_ENVIRONMENT_VARIABLE ADD TYPE VARCHAR(30);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-Add-environment-variables-type-to-denormalized-environment-variable', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 8, '9:3c21775b2c564150270041d21a40eeeb', 'addColumn tableName=DENORMALIZED_ENVIRONMENT_VARIABLE', 'Add TYPE column to DENORMALIZED_ENVIRONMENT_VARIABLE Table', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5745-Add-environment-variables-type-to-denormalized-environment-variable', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 8, '9:3c21775b2c564150270041d21a40eeeb', 'addColumn tableName=DENORMALIZED_ENVIRONMENT_VARIABLE', 'Add TYPE column to DENORMALIZED_ENVIRONMENT_VARIABLE Table', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-SQUASH-5890-environment-variable-data-migration-variable-type::bmsaddek
 -- Copy environment variable type in denormalized_environment_variable table if the variable has not been deleted
@@ -98,13 +98,13 @@ UPDATE DENORMALIZED_ENVIRONMENT_VARIABLE denormalized
         FROM ENVIRONMENT_VARIABLE environmentvariable
       WHERE denormalized.EV_ID IS NOT NULL AND environmentvariable.EV_ID = denormalized.EV_ID;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5890-environment-variable-data-migration-variable-type', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 9, '9:a959fab70e52c265fb5201e136318756', 'sql', 'Copy environment variable type in denormalized_environment_variable table if the variable has not been deleted', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-SQUASH-5890-environment-variable-data-migration-variable-type', 'bmsaddek', '../tm/tm.changelog-5.0.0.xml', NOW(), 9, '9:a959fab70e52c265fb5201e136318756', 'sql', 'Copy environment variable type in denormalized_environment_variable table if the variable has not been deleted', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-add-user-custom-delete-permission::pckerneis
 -- Add a column for custom delete permissions on CORE_USER table
 ALTER TABLE CORE_USER ADD CAN_DELETE_FROM_FRONT BOOLEAN DEFAULT TRUE NOT NULL;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-add-user-custom-delete-permission', 'pckerneis', '../tm/tm.changelog-5.0.0.xml', NOW(), 10, '9:587c2e26b3f1851dfe373d913415b988', 'addColumn tableName=CORE_USER', 'Add a column for custom delete permissions on CORE_USER table', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-add-user-custom-delete-permission', 'pckerneis', '../tm/tm.changelog-5.0.0.xml', NOW(), 10, '9:587c2e26b3f1851dfe373d913415b988', 'addColumn tableName=CORE_USER', 'Add a column for custom delete permissions on CORE_USER table', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-squash-5665-update-welcome-and-login-message::lmurat
 -- Adapt default welcome and login message to new front
@@ -113,25 +113,25 @@ UPDATE CORE_CONFIG
 WHERE STR_KEY = 'LOGIN_MESSAGE' AND VALUE = '<p><span style="color:#ff0000;">The administrator default login is <strong>admin/admin</strong> (you can change this password in the &quot;<em>My account (admin)</em>&quot; menu).</span></p><p>Go to the &quot;<em>Administration&quot;</em> menu (in the upper right corner) to create new users and projects, or change this default home message.</p><p>&nbsp;</p>'
    OR STR_KEY = 'WELCOME_MESSAGE' AND VALUE = '<p><span style="color:#ff0000;">The administrator default login is <strong>admin/admin</strong> (you can change this password in the &quot;<em>My account (admin)</em>&quot; menu).</span></p><p>Go to the &quot;<em>Administration&quot;</em> menu (in the upper right corner) to create new users and projects, or change this default home message.</p><p>&nbsp;</p>';
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5665-update-welcome-and-login-message', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 11, '9:ca54baa64370c1b6ef6c5cc7eb9aa1f5', 'sql', 'Adapt default welcome and login message to new front', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5665-update-welcome-and-login-message', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 11, '9:ca54baa64370c1b6ef6c5cc7eb9aa1f5', 'sql', 'Adapt default welcome and login message to new front', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-squash-5881-update-length-for-test-suite-name::lmurat
 -- Increase character limit for test suite name to 255
 ALTER TABLE TEST_SUITE ALTER COLUMN NAME TYPE VARCHAR(255) USING (NAME::VARCHAR(255));
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5881-update-length-for-test-suite-name', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 12, '9:5b9948a68e9d4e755d0086d77fd5fde3', 'modifyDataType columnName=NAME, tableName=TEST_SUITE', 'Increase character limit for test suite name to 255', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5881-update-length-for-test-suite-name', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 12, '9:5b9948a68e9d4e755d0086d77fd5fde3', 'modifyDataType columnName=NAME, tableName=TEST_SUITE', 'Increase character limit for test suite name to 255', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-squash-5384-taserver-eventbus-url-column::pckerneis
 -- Add EVENT_BUS_URL column to TEST_AUTOMATION_SERVER
 ALTER TABLE TEST_AUTOMATION_SERVER ADD EVENT_BUS_URL VARCHAR(255) DEFAULT null;
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5384-taserver-eventbus-url-column', 'pckerneis', '../tm/tm.changelog-5.0.0.xml', NOW(), 13, '9:af613a64edb306376a3413bd8e9f0799', 'addColumn tableName=TEST_AUTOMATION_SERVER', 'Add EVENT_BUS_URL column to TEST_AUTOMATION_SERVER', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5384-taserver-eventbus-url-column', 'pckerneis', '../tm/tm.changelog-5.0.0.xml', NOW(), 13, '9:af613a64edb306376a3413bd8e9f0799', 'addColumn tableName=TEST_AUTOMATION_SERVER', 'Add EVENT_BUS_URL column to TEST_AUTOMATION_SERVER', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Changeset ../tm/tm.changelog-5.0.0.xml::tm-5.0.0-squash-5749-add-test-technology-tag-to-automated-execution-extender::lmurat
 -- Add the automated test technology tag to the automated execution extender
 ALTER TABLE AUTOMATED_EXECUTION_EXTENDER ADD TEST_TECHNOLOGY VARCHAR(36);
 
-INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5749-add-test-technology-tag-to-automated-execution-extender', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 14, '9:1f07f54a1151d9fa8945667d5b538a7d', 'addColumn tableName=AUTOMATED_EXECUTION_EXTENDER', 'Add the automated test technology tag to the automated execution extender', 'EXECUTED', NULL, NULL, '4.29.2', '1246608562');
+INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-5.0.0-squash-5749-add-test-technology-tag-to-automated-execution-extender', 'lmurat', '../tm/tm.changelog-5.0.0.xml', NOW(), 14, '9:1f07f54a1151d9fa8945667d5b538a7d', 'addColumn tableName=AUTOMATED_EXECUTION_EXTENDER', 'Add the automated test technology tag to the automated execution extender', 'EXECUTED', NULL, NULL, '4.31.1', '2528086623');
 
 -- Release Database Lock
 UPDATE databasechangeloglock SET LOCKED = FALSE, LOCKEDBY = NULL, LOCKGRANTED = NULL WHERE ID = 1;
